You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@isis.apache.org by da...@apache.org on 2015/03/25 02:04:19 UTC

[8/9] isis git commit: ISIS-1028: fixing mvn dependency convergence issue; fixing two @PostConstruct in EventBusServiceDefault.

ISIS-1028: fixing mvn dependency convergence issue; fixing two @PostConstruct in EventBusServiceDefault.


Project: http://git-wip-us.apache.org/repos/asf/isis/repo
Commit: http://git-wip-us.apache.org/repos/asf/isis/commit/c5b794d6
Tree: http://git-wip-us.apache.org/repos/asf/isis/tree/c5b794d6
Diff: http://git-wip-us.apache.org/repos/asf/isis/diff/c5b794d6

Branch: refs/heads/master
Commit: c5b794d65dfc8edd279596de894665d6686a18fd
Parents: d8d882d
Author: Dan Haywood <da...@haywood-associates.co.uk>
Authored: Wed Mar 25 00:59:51 2015 +0000
Committer: Dan Haywood <da...@haywood-associates.co.uk>
Committed: Wed Mar 25 00:59:51 2015 +0000

----------------------------------------------------------------------
 .../apache/isis/applib/services/eventbus/EventBusService.java | 5 +++--
 core/viewer-restfulobjects-applib/pom.xml                     | 7 +++++++
 2 files changed, 10 insertions(+), 2 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/isis/blob/c5b794d6/core/applib/src/main/java/org/apache/isis/applib/services/eventbus/EventBusService.java
----------------------------------------------------------------------
diff --git a/core/viewer-restfulobjects-applib/pom.xml b/core/viewer-restfulobjects-applib/pom.xml
index 2a107f6..d8b60b8 100644
--- a/core/viewer-restfulobjects-applib/pom.xml
+++ b/core/viewer-restfulobjects-applib/pom.xml
@@ -74,6 +74,13 @@
         <dependency>
             <groupId>org.jboss.resteasy</groupId>
             <artifactId>resteasy-jaxrs</artifactId>
+            <exclusions>
+                <!-- clashes with axon -->
+                <exclusion>
+                    <groupId>commons-io</groupId>
+                    <artifactId>commons-io</artifactId>
+                </exclusion>
+            </exclusions>
         </dependency>
 
         <dependency>
diff --git a/core/applib/src/main/java/org/apache/isis/applib/services/eventbus/EventBusService.java b/core/applib/src/main/java/org/apache/isis/applib/services/eventbus/EventBusService.java
index 4582a8b..a4ac8eb 100644
--- a/core/applib/src/main/java/org/apache/isis/applib/services/eventbus/EventBusService.java
+++ b/core/applib/src/main/java/org/apache/isis/applib/services/eventbus/EventBusService.java
@@ -17,6 +17,7 @@
 package org.apache.isis.applib.services.eventbus;
 
 import java.util.Collections;
+import java.util.Map;
 import java.util.Set;
 
 import javax.annotation.PostConstruct;
@@ -73,7 +74,7 @@ public abstract class EventBusService {
      * therefore allow all services (singleton or request-scoped) to {@link #register(Object) register} themselves
      * with this service in their <code>@PostConstruct</code> and do the actual instantiation of the guava
      * {@link com.google.common.eventbus.EventBus} and registering of subscribers lazily, in {@link #getEventBusImplementation()}.
      * This lifecycle method ({@link #init()}) is therefore a no-op.
      *
      * <p>
      *     The guava {@link com.google.common.eventbus.EventBus} can however (and is) be torndown in the
@@ -82,7 +83,7 @@ public abstract class EventBusService {
      */
     @Programmatic
     @PostConstruct
-    public void init() {
+    public void init(final Map<String, String> properties) {
         // no-op
     }
 

http://git-wip-us.apache.org/repos/asf/isis/blob/c5b794d6/core/viewer-restfulobjects-applib/pom.xml
----------------------------------------------------------------------
@@ -73,7 +74,7 @@ public abstract class EventBusService {
      * with this service in their <code>@PostConstruct</code> and do the actual instantiation of the guava
      * {@link com.google.common.eventbus.EventBus} and registering of subscribers lazily, in {@link #getEventBusImplementation()}.
-     * This lifecycle method ({@link #init()}) is therefore a no-op.
+     * This lifecycle method ({@link #init(Map)}) is therefore a no-op.
      *
      * <p>